"""
    EMIL PartnerService

    The EMIL PartnerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.partner
from eis.partner.model.partner_type_custom_schema_dto import PartnerTypeCustomSchemaDto
globals()['PartnerTypeCustomSchemaDto'] = PartnerTypeCustomSchemaDto
from eis.partner.model.update_partner_type_request_dto import UpdatePartnerTypeRequestDto


class TestUpdatePartnerTypeRequestDto(unittest.TestCase):
    """UpdatePartnerTypeRequestDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testUpdatePartnerTypeRequestDto(self):
        """Test UpdatePartnerTypeRequestDto"""
        # FIXME: construct object with mandatory attributes with example values
        # model = UpdatePartnerTypeRequestDto()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
